/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "PluginArray.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMObject.h"
#include "gdom/GdomPluginArray.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomPluginArray.h"
#include "gdom/PrivateIntGdomPluginArray.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
gpointer toGDOM(WebCore::PluginArray* obj)
{
    return WebCore::cacheDOMObject<WebCore::PluginArray, GDOMPluginArray>(obj);
}
} /* namespace WebCore */
extern "C" {

GDOMPluginArray::GDOMPluginArray(PassRefPtr<WebCore::PluginArray> impl)
    : GDOMObject()
    , m_impl(impl)
{
}

GDOMPluginArray::~GDOMPluginArray()
{
    m_impl.get()->deref();
    WebCore::GDOMScriptInterpreter::forgetDOMObject(m_impl.get());

}

void
gdom_plugin_array_refresh (GdomPluginArray *thiz, gboolean reload)
{
    g_return_if_fail (thiz);
    WebCore::PluginArray * item = (gdom_plugin_array_get_private(thiz));
    g_return_if_fail (item);
    item->refresh(reload);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "PluginArray.h"
#include <gdom/GdomPluginArray.h>
#include <gdom/PrivateGdomPluginArray.h>
#include <gdom/PrivateIntGdomPluginArray.h>
#include <gdom/GdomPluginArrayprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomPluginArray, gdom_plugin_array, GDOM_TYPE_DOM_OBJECT);

/*
struct _GdomPluginArrayPrivate {
    class WebCore::PluginArray *item;
};

#define GDOM_PLUGIN_ARRAY_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_PLUGIN_ARRAY, GdomPluginArrayPrivate))
*/
G_END_DECLS
WebCore::PluginArray *
gdom_plugin_array_get_private(GdomPluginArray *request)
{
    GDOMPluginArray *res;
    res = static_cast<GDOMPluginArray*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::PluginArray*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_LENGTH,
};


static void gdom_plugin_array_finalize(GObject* object)
{
    /*GdomPluginArray* request = GDOM_PLUGIN_ARRAY(object);*/
    /*GdomPluginArrayPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_DOM_OBJECT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_plugin_array_parent_class)->finalize(object);
}

static void gdom_plugin_array__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomPluginArray *self = GDOM_PLUGIN_ARRAY(object);
    WebCore::PluginArray * gself = (gdom_plugin_array_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_plugin_array__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomPluginArray *self = GDOM_PLUGIN_ARRAY(object);
    WebCore::PluginArray * gself = (gdom_plugin_array_get_private(self));
    switch (prop_id) {
    case PROP_LENGTH:
    {
         g_value_set_ulong (value, gself->length());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_plugin_array_class_init(GdomPluginArrayClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_plugin_array_finalize;
    g_klass->set_property = gdom_plugin_array__set_property_fn;
    g_klass->get_property = gdom_plugin_array__get_property_fn;

    g_object_class_install_property (g_klass, PROP_LENGTH,
            g_param_spec_ulong ("length", /* name */
                "plugin_array_length", /* short description */
                "read-only  gulong PluginArray.length", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomPluginArrayPrivate));*/
}

static void gdom_plugin_array_init(GdomPluginArray* request)
{
    /*GdomPluginArrayPrivate* priv = GDOM_PLUGIN_ARRAY_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

